#
# spec file for package bash-completion
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor doc%{nil}

%if "%{flavor}" == "doc"
%define build_core 0
%define build_doc 1
%define nsuffix -doc
%else
%define build_core 1
%define build_doc 0
%endif

%global _name   bash-completion
Name:           %{_name}%{?nsuffix}
Version:        2.12.0
Release:        3.1
%if %{build_core}
Summary:        Programmable Completion for Bash
License:        GPL-2.0-or-later
%else
Summary:        The Documentation of Programmable Completion for Bash
License:        GPL-2.0-or-later
Provides:       bash-completion:%{_defaultdocdir}/%{_name}/AUTHORS
%endif
URL:            https://github.com/scop/bash-completion/
Source0:        https://github.com/scop/bash-completion/releases/download/%{version}/%{_name}-%{version}.tar.xz
Source1:        bash-completion-rpmlintrc
# PATCH-FIX-UPSTREAM bnc#717151 -- Terminal tab autocompletion error
Patch0:         %{_name}-2.4.patch
# PATCH-FIX-SUSE bnc#1012212 -- bash tab-autocompletion hangs on TAR-archiving with --create key
Patch1:         tar-completion.patch
# PATCH-FIX-SUSE boo#905348 -- tab completion with shell variable changes command line with backslash
Patch3:         FOO-dir-completion-boo905348.patch
# PATCH-FIX-SUSE
Patch4:         qdbus-qt5.patch
# PATCH-FIX-SUSE boo#889319
Patch5:         ls-completion-boo889319.patch
# PATCH-FIX-SUSE boo#940835
Patch6:         backtick-completion-boo940835.patch
# PATCH-FIX-SUSE bsc#946875
Patch7:         LVM-completion-bsc946875.patch
# PATCH-FIX-SUSE boo#940837, bsc#959299
Patch8:         respect-variables-boo940837.patch
# PATCH-FIX-SUSE boo#958462
Patch9:         rm-completion-smart-boo958462.patch
# PATCH-FIX-SUSE boo#963140
Patch10:        backticks-bsc963140.patch
# PATCH-FIX-SUSE boo#1090515
Patch11:        bash-completion-2.7-unRAR-remove.patch
# PATCH-FIX-SUSE boo#1190929
Patch13:        boo1190929-9af4afd0.patch
# PATCH-FIX-SUSE boo#1199724
Patch14:        bsc1199724-modules.patch
# PATCH-FIX-SUSE boo#1221414 -- shells/bash-completion: Bug
Patch15:        boo1221414-scp.patch
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildArch:      noarch
%if %{build_doc}
BuildRequires:  cmark
BuildRequires:  libxslt-tools
%endif
%if %{build_core}
Requires:       bash >= 5.1.16
%endif

%description
%if %{build_doc}
This package contains the package documentation file of the
package bash-completion.
%else
bash-completion is a collection of shell functions that take advantage
of the programmable completion feature of Bash 2.04 and later.

%package devel
Summary:        The Configuration of Programmable Completion for Bash
Provides:       bash-completion:%{_datadir}/pkgconfig/bash-completion.pc

%description devel
This package contains the package configuration file of the
package bash-completion.
%endif

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
autoreconf -fiv
%configure
%if %{build_core}
%make_build
%endif
%if %{build_doc}
pushd doc
    mkdir html
    for md in *.md
    do
        cmark $md --to html > html/${md%%.md}.html
    done
popd
%endif

%install
%if %{build_core}
%make_install
# shipping in latest systemd now
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/udevadm
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/nmcli
# shipping in latest util-linux now
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/cal
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/chsh
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/dmesg
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/eject
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/hexdump
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/hwclock
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/ionice
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/look
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/mount
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/newgrp
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/renice
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/rtcwake
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/su
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/umount
# shipping in devscripts now
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/bts
# shipped as part of libsecret
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/secret-tool
# Seems to be broken (boo#1161136)
rm -vf %{buildroot}%{_datadir}/bash-completion/completions/_adb
%endif
%if %{build_doc}
pushd doc
    mkdir -p  %{buildroot}%{_defaultdocdir}/%{_name}/html
    install -m 0644 html/* %{buildroot}%{_defaultdocdir}/%{_name}/html/
popd
install -m 0644 AUTHORS %{buildroot}%{_defaultdocdir}/%{_name}/
install -m 0644 README.md  %{buildroot}%{_defaultdocdir}/%{_name}/README
%endif

%files
%if "%{flavor}" == "doc"
%dir %{_defaultdocdir}/%{_name}
%{_defaultdocdir}/%{_name}/AUTHORS
%{_defaultdocdir}/%{_name}/README
%{_defaultdocdir}/%{_name}/html/
%else
%license COPYING
%dir %{_sysconfdir}/bash_completion.d/
%{_sysconfdir}/bash_completion.d/000_bash_completion_compat.bash
%{_datadir}/bash-completion
%config %{_sysconfdir}/profile.d/bash_completion.sh

%files devel
%dir %{_datadir}/cmake
%{_datadir}/cmake/bash-completion
%{_datadir}/pkgconfig/bash-completion.pc
# TRICK: bash-completion-devel does not require bash-completion.
# It would cause failure of directory ownership check.
# Own this directory to prevent it.
%dir %{_datadir}/bash-completion
%endif

%changelog
* Mon Jan 20 2025 Dominique Leuenberger <dimstar@opensuse.org>
- No longer ship completion for secret-tool, which belongs to
  libsecret and newly brings the completions by itself.
  https://github.com/scop/bash-completion/issues/1317
* Fri Mar 22 2024 Dr. Werner Fink <werner@suse.de>
- Add patch boo1221414-scp.patch
  * Do not replace the asignment of the array COMPREPLY with
    the shell function _comp_compgen_split (boo#1221414)
* Fri Feb 23 2024 Dr. Werner Fink <werner@suse.de>
- Remove also patch
  bash-completion-fix-missing-directory-completion-with-filename-pattern.patch
  as the problem is fixed upstream
* Fri Feb 23 2024 Dr. Werner Fink <werner@suse.de>
- Update to version 2.12.0:
  Features
  * _comp_backup_glob: add ucf generated backup files (351be1c)
  * _comp_backup_glob: require dash in dpkg backup files (59a57f9)
  * comp_compgen{filedir,set}: define exit status (7920c9d)
  * _comp_compgen_commands: align return value with other compgens (9d3362e)
  * _comp_compgen_commands: auto set -o filenames when appropriate (4d4839e)
  * _comp_compgen_commands: include dirs (b9c7b5d)
  * _comp_compgen_known_hosts: return 2 on usage error (43bb8f0)
  * _comp_compgen: support -i cmd and -x cmd (39cc200)
  * _comp_compgen: support -U var to unlocal var (b603535)
  * _comp_compgen: support option -C (6b3dfa5)
  * _comp_expand_glob: fail when no paths are generated (6b0a466)
  * _comp_get_fist_arg: support "-o GLOB" to skip optargs (0f14cc0)
  * _ip_addresses: auto ltrim colon completions when appropriate (ccdf953)
  * add _comp_compgen_split (542bf73)
  * add _comp_locate_first_arg (0384bd5)
  * airflow: add fallback 3rd party completion loader (bf5550b)
  * ansible:* add fallback 3rd party completion loader (5f8384e)
  * apt-get: prefer apt-cache in same dir as command (a731bfd)
  * b2sum: new completion (cd985df)
  * bash_completion: add function _comp_compgen_ltrim_colon (ce5889b)
  * black,blackd: add fallback 3rd party completion loader (47a1f05)
  * carton: support exec command completions (0eb3a21)
  * chezmoi: add 3rd-party completion loader (cobra) (31baa69)
  * conda: add 3rd-party completion loader (argcomplete) (c0f5ba2)
  * crc: add 3rd-party completion loader (cobra) (f10866e)
  * cz: add fallback 3rd party completion loader (b7ba70e)
  * dot: support filename extension .gv (be0010e)
  * dprint: add fallback 3rd party completion loader (e201e0e)
  * eog: add missing extension .heif (9e4a48f)
  * eog: associate with *.avif and *.webp (#1005) (f1c04b8)
  * eog: associate with *.heic and *.jxl (20c9cea)
  * eog: associate with *.pbm (#1006) (5472cc1)
  * feh: associate with y4m and heic/heif/avif (e252c73)
  * feh: deassociate with avci/avcs (af46f34)
  * flask: add fallback 3rd party completion loader (3e0d00d)
  * hash: new completion (#1013) (4d0bffb)
  * httpx: add fallback 3rd party completion loader (3f4861c)
  * ip: Add completion for monitor subcommand (fa696e6)
  * jungle: add fallback 3rd-party completion loader (c69845a)
  * keyring: add fallback 3rd party completion loader (8082602)
  * kontena: add fallback 3rd-party completion loader (5eef0ce)
  * lefthook: add fallback 3rd party completion loader (dc9650e)
  * mailman: prefer list_lists in same dir as command (a46ccf1)
  * mysql: prefer mysqlshow from same dir (643886c)
  * no empty command completion if no_empty_cmd_completion is on (faab292)
  * npm: add fallback 3rd-party completion loader (f1c085c)
  * nvm: add fallback 3rd-party completion loader (dea7e1d)
  * oc: add 3rd-party completion loader (cobra) (26b5f09)
  * pip{,3}: add fallback 3rd-party completion loader (e3cbfba)
  * pipenv: add fallback 3rd party completion loader (#1020) (6ecf5bd)
  * pytest: complete new --import-mode value (#1021) (2d636a3)
  * rtx: add fallback 3rd party completion loader (0628e22)
  * scp,sftp: prefer ssh from same dir to resolve options etc (d55f5e6)
  * ssh-copy-id,ssh-keygen: prefer ssh from same dir (5c1d270)
  * ssh-inscribe: add fallback 3rd party completion loader (7f2c197)
  * ssh: complete RequiredRSASize (#1064) (de15205)
  * tkn-pac: add 3rd-party completion loader (cobra) (d0f2604)
  * tkn: add 3rd-party completion loader (cobra) (161fc5d)
  * xrandr: comma separated --setmonitor third argument (8a76f3d)
  Bug Fixes
  * __load_completion: quoted compspec for variants (#1008) (0a2443e)
  * _cd_devices: /dev/cdc-* CDC device false positives (5250728)
  * _comp__init_set_up_service_completions: work around failglob (2529d40)
  * comp{first_arg,count_args}: count - as argument (e23a79e)
  * comp{first_arg,count_args}: count any arguments after -- (9bfd760)
  * _comp_command_offset: Support complete -C (80450ca)
  * _comp_compgen_fstypes: avoid unexpected expansions (a856d81)
  * _comp_compgen_help: allow dots to connect names in longopt (79dadfc)
  * _comp_compgen_known_hosts: work around bash-4.2 nounset (d2860cb)
  * _comp_compgen_split: work around nounset (f488f96)
  * _comp_compgen_term: replace completions by default (d3696a3)
  * _comp_compgen_usergroup: avoid directly overwriting COMPREPLY (d380498)
  * _comp_compgen: do not inherit -a for explicitly specified var (3c20766)
  * _comp_compgen: explicitly exclude cur from the target variable (5fe98f3)
  * _comp_count_args: check optarg correctly (874c503)
  * _comp_count_args: exclude <>& from wordbreaks as _comp_initialize (521d2bb)
  * _comp_count_args: ignore empty $3 (76eea74)
  * _comp_count_args: perform optarg check also on $3 (21d3122)
  * _comp_count_args: skip reassembling cword and words (3127703)
  * _comp_delimited: treat delimiter as a fixed string (571a0f7)
  * _comp_deprecate_func: argument order in usage error message (597f62f)
  * _comp_get_words: empty prev if unavailable (localvar_inherit) (d8b8eef)
  * _comp_initialize: fix completions of redirections without space (da16bf6)
  * _comp_initialize: protect against "localvar_inherit" (0cc8d83)
  * _comp_split,_comp_compgen: strip periods from error message (b3b6a7c)
  * _comp_split: update error message for the correct options (3c4a89c)
  * _comp_sysvdirs: work around nounset (da26178)
  * _filedir_xspec: clean up unused variable tmp (67f1189)
  * _get_cword_at_cursor,cvs: quote array length (201239c)
  * _get_first_arg: remove invalid doccomment (eb40f56)
  * _known_hosts: use array for options (work around SC2178,SC2179) (743d0a9)
  * _mock,rpm: avoid icase flag s/reg/rep/i of GNU sed (33c18ce)
  * _service: quote word (c2d7fb7)
  * _slackpkg: do not scan after cword (ecd1384)
  * 7z: remove redundant printf '%%s\n' "..." (20c2e32)
  * ant: work around custom IFS (584e567)
  * apt-cache: check all the words (84cfeda)
  * aptitude: do not use non-POSIX BRE \w (cd8c870)
  * aspell: use _comp_expand_glob against unexpected splitting (58d5176)
  * bash_completion: remove some unnecessary -a to _comp_compgen (636bb7c)
  * bts: update functions to generators and fix variable conflicts (7d2867c)
  * carton: remove a branch never happening (cd063f9)
  * chgrp: fix typo _comp_compgen{d  =&gt; _}filedir (#1063) (4c98ce5)
  * compat: find compat dir for prefix-install (b6d06bc)
  * completions/*: quote array assignments properly (848aa41)
  * completions/*: scan until cword instead of ${#words[@]}-1 (17e0cc3)
  * completions/*: work around localvar_inherit (e3a871d)
  * curl,koji: use _comp_compgen_help (f37f221)
  * curl,qemu: avoid using POSIX character classes for mawk (d60c530)
  * curl: colon handling for IPv6 address completions (8508d1d)
  * cvs,mutt,pkg_delete: quote prefix to remove for literal matching (533903e)
  * cvs: avoid variable conflicts (0d145c9)
  * dict: nounset error when host/port not set (57191e2)
  * dict: protect splitting from custom IFS (b31fe1e)
  * dict: work around bash-4.2 array nounset (d76dd9e)
  * dict: work around bash-4.3 ${v+"$@"} with custom IFS
  Unable to render expression.
  * ${v+"$@"} with custom IFS (cc21298)
  * dmypy: protect against "localvar_inherit" (768ce65)
  * dpkg-source: filter completions by cur (dbcef6e)
  * filedir: work around bash-4.2 compgen -f -- "''" (c8bb123)
  * fix problems with set -o nounset (9c3e196)
  * gdb: fix regression that fails to generate command names (ca8e240)
  * gdb: remove duplicate candidates (532fc05)
  * gdb: use POSIX-compatible find expression (73938cd)
  * gdb: work around bash 4.4 ${v+"$@"}
  * get_words: work around bash-4.3 connected ${v+"$@"}
  * getent: check noargopts (6143f25)
  * getent: work around localvar_inherit (a12f438)
  * gzip,isort: fix typo _comp_com{gp =&gt; pg}en (462feb3)
  * iperf,puppet: use {m,n} instead of ? and + for POSIX sed (3f0322b)
  * iperf: work around failglob with backslash in bash-5.0 (979f04f)
  * ip: Remove non-existent route completion (3b9ce4d)
  * isql: work around nounset (cb7007a)
  * java,kldload: use _comp_compgen for filename-based mod names (81adc6c)
  * java: localize cur (ec0068d)
  * kcov,povray: quote array expansions to avoid extra processing (215edab)
  * kldload,mplayer,mutt: work around nounset (5330fbe)
  * kldunload: remove unused -X option (35017d2)
  * known_hosts_real: match *.pub instead of *pub (470a644)
  * known_hosts_real: use _comp_expand_glob to avoid failglob (672215e)
  * known_hosts_real: work around nounset (07c619a)
  * lilo,rpcdebug,slapt-{get,src}: work around nounset (cfc3eda)
  * lvm: replace array slices with existing utility (ea49840)
  * lvm: update call to sub-command (30494f7)
  * make: handle multiple short options in skipping arguments (24c80c9)
  * make: typo fix in a code comment (e72cc82)
  * mdadm,update-alternatives: fix leak variable (14cd53b)
  * medusa: filter completions by the current word cur (f3ae706)
  * mr: avoid ${var/pat/$'...'} for compat42 in bash >= 4.3 (b5ae5fa)
  * mr: exactly match command names (800b103)
  * mutt: avoid unexpected word splitting (3183e67)
  * mutt: fix use of regex in the glob context (63924e6)
  * mutt: rewrite ${cur/#!/X} to X${cur:1} against patsub_replacement (6b8f82b)
  * mutt: use _comp_dequote for safe eval (f98379d)
  * openssl: avoid variable conflicts (a31906c)
  * openssl: fix variable i leak (83844b7)
  * perl: fix ineffective condition in an awk script (302dc52)
  * perl: helper call regression from 01611dd (b85263a)
  * pgrep: do not rely on uncontrolled IFS (99e38b2)
  * portinstall: use awk and _comp_compgen to filter completions (791f56c)
  * povray,sbopkg: check filetype (434eb08)
  * povray: process each element against patsub_replacement (0afc2e4)
  * povray: quote an argument properly (0a240bd)
  * ps,ss: avoid extra expansions by -W "$(...)" in _comp_delimited (cb347cb)
  * pydoc: specify -a to _comp_compgen_filedir (34a91e9)
  * pytest: do not filter underscores from parsed option arg choices (ea13241)
  * python: avoid variable conflicts (bef94c3)
  * python: complete filenames for script arguments (#1018) (397a49d)
  * python: complete micropython and pyston script args consistently (5b60ccc)
  * qdbus: remove cur and all the rest arguments (531b751)
  * replace \s with [[:space:]] for POSIX sed/awk (1989ba9)
  * ri: avoid interference on existing COMPREPLY (0a9d931)
  * ri: fix wrongly quoted options to compgen (5248bbf)
  * ri: properly split methods (910a5a0)
  * ri: split classes using _comp_split (c95baa1)
  * ri: work around localvar_inherit (9d6ff68)
  * sbopkg: add ; mandatory before } in POSIX sed (b286d53)
  * sbopkg: work around nounset (9709bdf)
  * scp: nounset mode error on unknown suboption, bash 4.2 (82ca8d9)
  * ssh-copy-id: call ssh, not -copy-id for suboption completion check (473278f)
  * ssh-keygen: call ssh, not -keygen to resolve supported protocols (d569ea2)
  * ssh-keygen: first arg to ssh query for protocol versions (8a0a71e)
  * ssh: avoid variable conflicts (f2df91d)
  * ssh: fix wrong quoting inside compgen -W (febb3b3)
  * ssh: remove -a of generators (55c5c45)
  * ssh: remove unnecessary -a to _comp_compgen (992f28e)
  * ssh: resolve relative ssh_config Include correctly (4ac86e8)
  * ssh: use _comp_compgen for _comp_xfunc_ssh_identityfile (05e70ed)
  * ssh: work around bash-4.2 nounset (4447f83)
  * ssh: work around bash-4.2 nounset (d0695d0)
  * sudo: use $1 (sudo) as $root_command (329ca0e)
  * svcadm: fix ineffective IFS for splitting (1fd456e)
  * svcadm: use the first matching name as command (1870d5e)
  * sysbench: fix extraction of test-name option (cc246a1)
  * timeout: always treat word after duration as command (0d0531b)
  * tipc: remove filtered-out elements (75b36b2)
  * update-alternatives: quote dirname (1205ed1)
  * update-alternatives: suppress error for non-existent directory (adbdab8)
  * update-alternatives: work around localvar_inherit (1d9e19c)
  * upgradepkg: use _comp_compgen for _comp_cmd_upgradepkg (a0973d7)
  * use _comp_compgen_split to avoid extra expansions by -W "$(...)" (49997d0)
  * use _comp_compgen_split to split and filter words (158b8ba)
  * use _comp_compgen_split while keeping filtering by $cur (a00ee19)
  * use _comp_compgen for word list (83f033f)
  * use _comp_split while keeping filtering by $cur (509e642)
  * use compgen -P prefix -W '"${arr[@]}"' against patsub_replacement (45d036a)
  * use XPG4 awk in Solaris (cdd6da9)
  * wol: filter IP addresses by cur (c3505c5)
  * wtf: quote array assignment (44c1d12)
  * xfreerdp: support the new form of the option /list:kbd (d8cadfe)
  * xfunc ssh identityfile: localize change to cur (76b5726)
  Performance Improvements
  * _comp_count_args: skip reinitializing cword and words (29398ef)
  * mutt: return earlier on empty cur (a244587)
  * portinstall: return earlier for -lLo and non-existent file (395e463)
  * vncviewer: set nocasematch inside subshell (5ed0020)
- Delete patches as fixed upstream
  * fix-curl-help-completion-bsc1200791.patch
  * fix_quote_readline_by_ref.patch
- Port patches
  * FOO-dir-completion-boo905348.patch
  * LVM-completion-bsc946875.patch
  * backtick-completion-boo940835.patch
  * backticks-bsc963140.patch
  * bash-completion-2.4.patch
  * bash-completion-2.7-unRAR-remove.patch
  * bash-completion.changes
  * bash-completion.spec
  * boo1190929-9af4afd0.patch
  * bsc1199724-modules.patch
  * ls-completion-boo889319.patch
  * qdbus-qt5.patch
  * respect-variables-boo940837.patch
  * rm-completion-smart-boo958462.patch
  * tar-completion.patch
- Do not apply patch
  bash-completion-fix-missing-directory-completion-with-filename-pattern.patch
  as not known how to port and if this is required
* Thu Aug 17 2023 Dr. Werner Fink <werner@suse.de>
- Modify patches
  * ls-completion-boo889319.patch
  * rm-completion-smart-boo958462.patch
  to avoid skipping spaces after last word on command line (boo#1210974)
- Add patch fix_quote_readline_by_ref.patch
  * Do not escape leading ~ nor backslash and avoid empty quoting
* Sun Apr  2 2023 Callum Farmer <gmbr3@opensuse.org>
- Move cmake config files to devel
* Tue Jul 26 2022 Otto Hollmann <otto.hollmann@suse.com>
- Add patch fix-curl-help-completion-bsc1200791.patch (bsc#1200791)
  * List all options for `curl --<TAB>`
* Mon May 23 2022 Dr. Werner Fink <werner@suse.de>
- Add patch bsc1199724-modules.patch (bsc#1199724)
  * Enable upstream commit to list ko.zst modules as well
* Fri Jan 28 2022 Dirk Müller <dmueller@suse.com>
- remove PS1-completion-boo903362.patch as it breaks on non-bash
  shells and the original problem in
  bsc#903362#c9 does not occur anymore
- add versioned dependency to bash versions that have the fix
* Mon Oct  4 2021 Dr. Werner Fink <werner@suse.de>
- Add patch boo1190929-9af4afd0.patch for boo#1190929
  add support for compeletion modinfo completion recognize .ko.zst
  as well as .ko.bz2
* Mon Sep 28 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to _multibuild. The pre_checkin.sh script was quite
  broken anyway and it was less effort to convert than to try to
  fix that one.
* Mon Sep 28 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Do not BuildRequire util-linux: there is no need to have this in
  the build root.
- Drop cmake BuildRequires: this is only here for the
  /usr/share/cmake directory ownership, which in turn even causes
  problems of left-over directories (e.g. install bash-completion,
  on a system without cmake, uninstall bash-completion,
  /usr/share/cmake remains left on the disk).
* Tue Aug 18 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 2.11:
  * _known_hosts_real: check that ruptime is present before calling
    (#390)
  * totem: reuse kaffeine completions (#372)
  * __reassemble_comp_words_by_ref: avoid triggering nounset on
    indirect references
  * lintian: complete paths for Ubuntu's .ddeb and Debian's buildinfo
    files (#397)
  * ip: complete route add table arg
  * ip: style fixes similar to ip-netns
  * ip: add more completions for ip-rule
  * ip: add support for netns (#391)
  * ip: improve completion of route subcommands (#326)
  * unzip, zipinfo: complete *.aar (#428)
  * ssh: add new -Q completions in OpenSSH 8.2p1 (#400)
  * python: support executables with minor version (#389)
  * insmod, modinfo, modprobe: support xz compressed modules (#401)
  * tshark: complete -r arg with all filenames (#422)
  * openssl: update -starttls completions (#403)
  * _filedir*: update link to bug-bash discussion on -X (#404)
  * test/python: add testcase for submodule completion
  * Release 2.11
  * extra/make-changelog: check and output usage message
  * pre-commit: anchor exclude patterns
  * pytest: rewrite in bash, support toplevel funcs, avoid nondef ones
    and classes
  * test/xfreerdp: skip --help failure cases
  * test/tshark: fix multiple -O completion with no http2 support
  * test/ant: avoid complete-ant-cmd.pl interference with ANT_ARGS
  * _xinetd_services: avoid nounset error on bash 4.2
  * pre-commit: upgrade isort to 5.1.4
  * pre-commit: upgrade pyupgrade to 2.7.2
  * pre-commit: add pyupgrade, run it
  * test/ant: gitignore all target cache files
  * _known_hosts_real: exclude Host negations
  * pre-commit: upgrade isort to 5.0.7
  * pre-commit: update shellcheck-py URL
  * test/inputrc: do not set print-completions-horizontally
  * test/inputrc: comment typo fix
  * pytest: complete async test class methods
  * __get_cword_at_cursor_by_ref: fix regression on bash 4.2
  * test: upgrade markdownlint-cli to 0.23.2
  * _known_hosts_real: avoid errors in nounset mode on Ubuntu 14 and
    16
  * _longopt: exclude too many dashes, allow underscores, require ends
    with alnum
  * _included_ssh_config_files: support globs
  * _known_hosts_real: prevent unwanted pathname expansion on host
    entries
  * test/shfmt: upgrade to 3.1.2, reformat with it
  * test/_known_hosts_real: add explicit no globbing test case
  * test: upgrade mypy to 0.782
  * CONTRIBUTING.md: add posix and nounset mode item
  * test: upgrade mypy to 0.781
  * test: upgrade perltidy to 20200619
  * _known_hosts_real: fix completion of Host entries after a wildcard
    etc
  * _known_hosts_real: fix # handling in ssh configs
  * test: upgrade flake8 to 3.8.3
  * test/xhost: multiple expected result handling fixes
  * test/slapt-src: single expected result handling fixes
  * test: partial hostname completion fixes
  * test: simplify completion parsing
  * test/dpkg-query: mark as xfail on non-Debian based systems
  * .gitignore: clean up some no longer needed ignores
  * test/lspci: skip -A arg test if lspci fails -A help, e.g. busybox
    lspci
  * test: regex escape our magic mark for completeness
  * test: upgrade mypy to 0.780
  * test/_known_hosts_real: don't modify class scoped base expected
    list
  * test/_known_hosts_real: reset COMP_KNOWN_HOSTS_WITH_HOSTFILE
    between tests
  * test/_known_hosts_real: tolerate duplicates
  * bash_completion: trivial cleanups
  * gcc: avoid errors in nounset mode
  * pytest: fix test class method completion with BSD awk
  * man, mutt: avoid errors in nounset mode on Ubuntu 14 and 16
  * java, make: avoid errors in nounset mode on Ubuntu 14 and 16
  * README: document GNU make build requirement
  * pytest: add test class method completion
  * _known_hosts: avoid errors in nounset mode and no arguments
  * bash_completion: fix array set checks with empty elements in them
  * *: avoid more errors in nounset mode
  * cfrun: fix $hostfile leak
  * _command_offset, route: cleanups
  * *: avoid more errors in nounset mode
  * qemu: add -machine arg completion
  * qemu, sbopkg: avoid unintentional globbing on option arg
    completions
  * test: enable shellcheck SC2035
  * *: drop support for bash 4.1
  * _init_completion: fix unassigned redirect completion in nounset
    mode
  * ip: route shfmt, arithmetic evaluation
  * _filedir: avoid unbound variable error on Ubuntu 14 and 16
  * _pids, _pgids, _pnames: improve shfmt formatting
  * scp, sftp, ssh: fix completion on options bundled with -4/-6
  * modprobe, tshark, _included_ssh_config_files: use [[ ]] instead of
    [ ]
  * test/runLint: warn about [ ] instead of [[ ]] use
  * test: skip various tests if we don't get a useful usage message
  * *: mark nounset mode as supported, issues with it are bugs now
  * *: avoid more errors in nounset mode
  * *: avoid more errors in nounset mode
  * *: avoid more errors in nounset mode
  * test/inputrc: comment and whitespace tweaks
  * *: avoid more errors in nounset mode
  * test/unit: sort files included in dist
  * test/unit: include test_unit_known_hosts_real.py in dist
  * bash_completion: line wrapping tweaks, NFC
  * 7z: fix -o/-w attached arg completion
  * postfix: try to arrange a fake tty so we can tickle the usage
    message out
  * _bashcomp_try_faketty: new function to try running command with a
    fake tty
  * mr: avoid herestrings, simplify command parsing
  * test/mr: handle missing "clean" with skipif
  * test: mark known non-ASCII issues with test suite as xfail
  * dpkg-deb: add --raw-extract and -X arg completions
  * test: add some dpkg-query test cases
  * dpkg-deb: fix --show/-W completion
  * test: upgrade markdownlint-cli to 0.23.1
  * *: use more arithmetic evaluation
  * test: try harder to restore environment and cwd on failures
  * *: use $ifs for storing/restoring $IFS
  * test/irb: xfail options test if --help is not available
  * test: upgrade flake8 to 3.8.1
  * test: pre-commit config cleanups, ordering
  * test: upgrade pre-commit to 2.4.0+, drop shfmt kludge
  * test: sync shfmt and shellcheck configs
  * test: shfmt bashrc
  * test: remove unused run-shellcheck, shellcheck is in pre-commit
    now
  * test: remove old test suite code no longer used \o/
  * test/_known_hosts_real: port remaining test cases to
    pytest+pexpect
  * test: remove more no longer needed old test suite code
  * test/_known_hosts_real: port more test cases to pytest+pexpect
  * test/_get_cword: port remaining test case to pytest+pexpect
  * test: replace some echos with printfs
  * test/_filedir: fix shutil.rmtree on Python < 3.6
  * test/_expand: port remaining test cases to pytest+pexpect
  * test: drop some no longer needed old test suite code
  * test/_filedir: port remaining test cases to pytest+pexpect
  * test: run all Travis jobs on dist: bionic
  * test: drop not needed sudo on Travis
  * test/_filedir: port more test cases to pytest+pexpect
  * test/__expand_tilde_by_ref: port remaining test cases to
    pytest+pexpect
  * test/_get_comp_words_by_ref: convert remaining test cases to
    pytest+pexpect
  * test: run pytest --verbose in docker
  * lftp: use "bookmark list" command to list bookmarks
  * test: drop some no longer needed old test suite code
  * test/slapt-src: convert remaining test case to pytest+pexpect
  * _xfunc: simplify
  * apt-cache: avoid nonzero exit code from _apt_cache_packages
  * test/slapt-get: convert remaining test case to pytest+pexpect
  * test/secret-tool: add to test command list
  * test/scp: port remaining test case to pytest+pexpect
  * test/umount: convert remaining test case to pytest+pexpect
  * secret-tool: new completion
  * apt-get: complete build-dep with dirs
  * travis: use golang 1.14 for shfmt
  * *: run all shell code through shfmt -s
  * pre-commit etc: add shfmt
  * test: fix incorrect fixtures/shared/default xfails/expectations
  * test: upgrade markdownlint to 0.23.0
  * nmap: simplify help scraping a bit, don't try to emit unnecessary
    newlines
  * test: prefix fake test commands with underscore
  * test: port most umount test cases to pytest+pexpect
  * test: add note about unescaped assert_complete single return
    values
  * editorconfig: apply yaml settings to .yaml too
  * pre-commit: use local perlcritic hook
  * *: doc and comment link updates
  * pre-commit, *.md: add markdownlint, address findings
  * README: clarify loading automatically on demand
  * ssh-keygen: -O arg updates and improvements
  * ssh-keygen: add -b arg completions according to specified -t
  * ssh-keygen: option and arg completion updates for new versions
  * _command: improve commentary
  * reportbug, scp, sftp, svn: use compgen -c instead of _command
  * find: fix -exec etc argument and its completion
  * extra: trigger docker builds only on test-cmd-list.txt changes
  * test: add script to maintain list of executables for full test
    coverage
  * test: run lint tests on Travis in a quickish separate first stage
  * test/make: mark more cases as requiring command
  * make: add bmake alias
  * test: run pre-commit on host instead of docker
  * test: add perlcritic to pre-commit, run on all perl
  * *: remove some unused variables, thanks to shellcheck SC2034
  * *: various loop iteration improvements
  * crontab: fix loop over already given args
  * apt-cache: fix command mode handling
  * doc: add loop variable naming guideline
  * test: make at-point completion tests easier
  * ssh, xsltproc: address shellcheck SC2006
  * scp: work around shellcheck SC1003
  * mutt: address shellchec SC2236
  * wget: address shellcheck SC2116
  * pytest: address shellcheck SC2002
  * bash_completion, java, tipc: for loop whitespace consistency
    tweaks
  * *: more arithmetic evaluation cleanups, thanks to shellcheck
    SC2004
  * __reassemble_comp_words_by_ref, java: address and work around
    shellcheck SC2102
  * test: enable parallel pre-commit shellcheck
  * test: remove shellcheck severity filter, add explicit disables
    instead
  * doc: recommend arithmetic evaluation
  * *: array subscript cleanups
  * ssh-keygen: -s and -n completion improvements
  * *: enable and address shellcheck SC2053
  * bash_completion, invoke-rc.d, svcadm: trivial cleanups
  * *: replace various conditional expressions with arithmetic
    evaluation
  * carton: fix command parsing with BSD sed
  * nmap: fix option parsing with BSD sed
  * test/alias: port remaining test case to pytest+pexpect
  * test: generalize complete at point test
  * test/cd: fix test_dir_at_point for setups that repeat "trailer"
  * pytest: add some option arg (non-)completions
  * pytest: complete test classes
  * pgrep, pkill: add --ns and --nslist arg completions
  * test: run skipif and xfail commands without caring if they output
    or not
  * test: make it possible to not care whether command did output or
    not
  * test/xfreerdp: skip xfreerdp kbd test if kbd-list returns empty
  * test: tolerate duplicates from compgen actions
  * test: bump shellcheck severity to warning + some disables
  * *: address shellcheck SC2046
  * test/lib/library.sh: address shellcheck SC2125
  * java, pkgadd, sysbench: address shellchec SC2124
  * scp: address shellcheck SC2089 and SC2090
  * _filedir_xspec: address shellcheck SC2140
  * rpm, ssh, umount.linux: address shellcheck SC2120
  * cvs, modprobe, sh: address shellcheck SC2209
  * mutt: address shellcheck SC2088
  * _upvar, _upvars, _variables, rpm: address shellcheck SC1083
  * test/run: address shellcheck SC2164
  * renice: address shellcheck SC2254
  * tipc: comment grammar and spelling fixes
  * man, perl, route, tipc: address shellcheck SC2053
  * info, java: address shellcheck SC2153
  * quote_readline: fix $ret leak
  * test: upgrade shellcheck to 0.7.1
  * test/printenv: xfail if --help doesn't contain options (e.g.
    busybox)
  * test/aptitude: require command where necessary
  * _known_hosts_real, op: address shellcheck SC2184
  * test: don't run shellcheck on completions/.gitignore
  * protoc: complete all --*_out without more specific handling with
    dirs
  * sysbench: add --test= deprecation TODO
  * pkgadd: indentation fix
  * chronyc, wvdial: address shellcheck SC2178
  * java, pkgadd, sysbench: address shellcheck SC2124
  * mplayer: address shellcheck SC1078 false positive
  * smartctl: hush shellcheck SC2054 false positives
  * *: address shellcheck SC2221 and SC2222
  * bash_completion: address shellcheck SC2220
  * crontab, wodim: silence shellcheck SC2191 and SC2192
  * aptitude: add some option arg (non)completions
  * aptitude: parse options list from --help, hardcode less
  * test/aptitude: add some test cases
  * *: argument interation improvements
  * *: whitespace tweaks
  * apt-get etc: use _apt_cache_packages from apt-cache
  * pre-commit: run most python checks on helpers/python too
  * test/ldd: xfail if --help is not implemented
  * test/printenv: require command for arg completion test
  * printenv: indentation fixes
  * test: upgrade mypy to 0.770
  * test: split dependencies requiring Python 3.6.1+ to requirements-
    dev.txt
  * git: trigger docker rebuild on pre-commit config change
  * test: require openssl command for option argument tests
  * test: move perltidy to pre-commit, run with --converge
  * test: move shellcheck to pre-commit
  * test: ignore flake8 messages that are in black's domain
  * _xinetd_services: look up from $BASHCOMP_XINETDDIR, add some unit
    tests
  * printenv: new completion
  * copyright: add 2020
  * test: fix CompletionResult.__eq__ UnboundLocalError
  * test: run pre-commit in tools container
  * test: shellcheck tweaks
  * test: add isort to pre-commit, run it
  * test: add flake8-bugbear
  * test: install black for Python 3.6 too
  * pre-commit: add config with black, flake8, and mypy
  * test: drop redundant black args from docker runs
  * *: python type hint fixes and improvements
  * extra/make-changelog: run through black
  * test/totem: add basic test case
  * test/cd: remove unused import
  * openssl: complete -writerand with filenames
  * openssl: parse available options from $command -help
  * openssl: support getting digest list from more recent openssl
    versions
  * nmap: handle options split on equals sign
  * nmap: parse options from -h output
  * test/cd: make dir_at_point produce better debuggable failures
  * test/cd: convert remaining test case to pytest+pexpect
  * test: remove some no longer needed old test suite code
  * test/chown,sudo: parametrize special case test, improve xfail
    targeting
  * test/tsig-keygen: require command for test_options
  * test/upgradepkg: port remaining test case to pytest+pexpect
  * tsig-keygen: new completion
  * test: host helper lint and usage fixes
  * test: port some _known_hosts_real unit tests to pytest+pexpect
  * test: remove some no longer needed tcl/expect code
  * test: fix spurious hosts fixture failure without avahi-browse
    installed
  * test: port some scp test cases to pytest+pexpect
  * test: port remaining finger, sftp, ssh, and xhost cases to
    pytest+pexpect
  * lilo: work around shellcheck false positive
  * test/ipcalc: fix tests with busybox ipcalc
  * chromium-browser, firefox: complete on *.txt (#379)
  * README.md: add introduction
  * ipcalc: new completion
  * *: complete commands when prefixed with a backslash
  * test/wol: don't fail MAC test if test system has /etc/ethers
    entries
  * test/dnssec-keygen: allow more alternatives in algorithm
    completion
  * lilo: don't complete on commented out labels
  * lilo: honor -C when completing labels
  * lilo: add -B and -E completions
  * Source user completion only if it's a file (#409)
  * jarsigner: complete on *.apk too (#386)
  * cryptsetup: add luksChangeKey arg completion (#380)
- Refresh and reorder all patches and use autosetup macro
- Run spec-cleaner
  * Remove rpm groups
* Tue Jun 23 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Modify qdbus-qt5.patch: only modify Makefile.am; Makefile.in is
  auto-generated based on the .am file.
- Add libtool BuildRequires and explicitly call autoreconf: unless
  we do this, there is a chance that the build modifies the above
  mentioned .am and .in files with different timestamps, which in
  turn triggers an implicit autoreconf. Without libtool present
  though, this will fail.
* Tue May 12 2020 Dirk Mueller <dmueller@suse.com>
- fix extra tokens at the end of %%endif directive build errors
* Mon Apr 13 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Improve patch to fix lookup of qdbus-qt5 completion, previously
  it was only loaded if qdbus was used first:
  * qdbus-qt5.patch
* Sat Mar 28 2020 Michal Suchanek <msuchanek@suse.de>
- Fix completion excluding directories (boo#1167952).
  * bash-completion-fix-missing-directory-completion-with-filename-pattern.patch
* Fri Mar 13 2020 Fabian Vogt <fvogt@suse.com>
- Add patch to also complete qdbus-qt5:
  * qdbus-qt5.patch
* Fri Jan 17 2020 Dr. Werner Fink <werner@suse.de>
- Remove _adb as it seems to be broken anyway (boo#1161136)
* Sun Jan  5 2020 Martin Liška <mliska@suse.cz>
- Update to version 2.10:
  * perltidy: associate *.t (#338)
  * perl: fix completion with space between option and argument
  * _variables: add TERM and LC_* completion (#353)
  * autotools: Replace pkgdatadir with datadir
  * pkg-config: Relative paths
  * pkg-config: generate Name from autotools PACKAGE
  * ssh: option and argument completion updates (#332)
  * test_arp: Skip if ARP tables are empty
  * test_chromium_browser: Skip test_2 if 'chromium-browser --help'
    fails
  * test_rpm2tgz: Fix expected output
  * cppcheck: Add new standards to --std option. (#356)
  * apt-get: fix pkg version completion if it contains a colon (#351)
  * test: bump black to >=19.10b0
  * ssh, scp, sftp, ssh-copy-id, curl: improve identity file
    completion
  * update-rc.d: indentation fix
  * update-rc.d: remove dead code
  * screen: add serial device basic arg (non)completion
  * screen: add //telnet completion
  * test: add some trivial perl -E/-e cases
  * perl: indentation fixes
  * curl: make @filename completion do the right thing with dirs
  * _filedir: avoid duplicate dirs internally, and a compgen -d call
    for files
  * _filedir: remove unused $x
  * bash_completion.sh: shellcheck SC2086 fixes
  * test: shellcheck config cleanups
  * shellcheck: add some option arg (non)completions
  * test: fix cpio users test in presence of usernames with whitespace
  * test: python typing fixes
  * test: add minimal mypy config
  * .gitignore: mypy cache
  * makepkg: fix option completion
  * test: mark dcop and mr testcases requiring the cmd as such
  * CONTRIBUTING: disable e-mail bug gateway due to spam
  * carton: new completion
  * op: direct command parsing stderr to /dev/null
  * test: adjust java expectations based on whether jars can be listed
  * valgrind: look tool names from lib/*-linux-gnu dirs too
  * test: xfail locale-gen option completion if --help is not
    available
  * _sysvdirs: always return 0
  * java: don't assume jar is installed
  * travis: test with Debian 10
  * wine: install for wine-development and wine-stable too
  * travis: generate dist tarball on alpine
  * dmypy: new completion
  * test: add require_longopt xfail helper, use it
  * test: mark more tests that parse command output as requiring
    command
  * sysctl: invoke completed sysctl instead of one from path to get
    variables
  * screen, smartctl, update-alternatives: _parse_help, drop hardcoded
    option list
  * lintian-info: _parse_help, add more option arg (non)completions
  * gprof: _parse_usage, drop hardcoded option list
  * test: fix retrieving command to test from request
  * travis: pass NETWORK as env var, so we can actually use it
  * test: xfail MAC address completion without networking
  * test: ignore _makepkg_bootstrap in makepkg test env
  * test: hush flake8-bugbear B010
  * test: don't sort expected completion lists under the hood
  * test: add bunch of basic option parsing test cases
  * test: always run tests which don't require tested command
  * test: explodepkg and upgradepkg test fixes
  * test: mark sbcl-mt xfail due to whitespace split issues
  * _terms: search directly from various terminfo dirs
  * _terms: combine and simplify somewhat
  * pkg-get: fix $i leak
  * pkgutil: fix $i leak
  * test: portinstall/upgrade test case and setup fixes
  * lvm pv*, vg*: parse help instead of hardcoding option list
  * ipv6calc: parse help instead of hardcoding option list
  * test: avoid some sed -r/-E runLint false positives
  * test: use sh +* as ccache command test case
  * java: make jar/zip listing work with unzip
  * test: installpkg test fixes
  * test: fix acroread fixture dir
  * test: remove unnecessary returns after pytest.skip
  * test: avoid gnome-mplayer core dump on Ubuntu 14
  * xvfb-run: new completion
  * test: skip gssdp-discover --message-type when option not available
  * test: expect failures for bc without --help useful with _longopt
  * test: don't expect a .tox dir in fixture
  * test: drop sourcing our no longer existing profile.d script
  * tox: include -- in option completions
  * tox: complete defaults after a --
  * gssdp-discover: new completion
  * test: register our pytest markers to hush warnings from 4.5+
  * test: fix required pytest version
  * ip: invoke the tool as $1
  * README: drop distro badges, link to Repology instead
  * chromium-browser: add --proxy-server arg completion
  * test: source our profile.d test env script in docker
  * influx: new completion
  * README: badge title tweaks
  * tox: do simple parse on tox.ini if --listenvs* yields nothing
  * test: add basic tox fixture
  * man: fall back to _parse_usage for _parse_help
  * test_wsimport: xfail options test on unparseable -help
  * test: don't try to install black on Python < 3.6
  * pgrep: fix fallback to _parse_usage
  * test: xfail unparseable mock and munin-node-configure --help cases
  * test_pwdx: xfail more unparseable help cases
  * build: make pytest executable configurable, look for pytest-3 too
  * test: enforce minimum pytest version
  * test: zopflipng flake8 fix
  * test: xfail getent and pwdx option completions with unparseable
  - -help
  * test: add more basic _parse_help use test cases
  * test: add bunch of basic _parse_help use test cases
  * .gitignore: add configure.lineno
  * badblocks: fix $i leak
  * postfix: option completion is expected to fail at the moment
  * cal: try _parse_help before _parse_usage
  * test: add bunch of basic _parse_usage use test cases
  * chsh, pwck: try _parse_help before _parse_usage
  * test: add basic autossh test
  * test: convert more _filedir unit tests to pytest+pexpect
  * test: flake8 fix
  * test: convert bunch of _filedir unit tests to pytest+pexpect
  * test: convert finger partial test case to pytest+pexpect
  * README: add some badges, tweak existing
  * test: port _variables unit tests to pytest+pexpect
  * test: port compgen and quote tests to pytest+pexpect
  * iconv, lz4, tipc, xsltproc: replace some seds with compgen -X
  * test: disallow Alpine failure on Travis
  * _pnames: adapt for busybox ps, rewrite in pure bash
  * test: run our docker script in test containers by default
  * test: use one Dockerfile for all dists
  * test_ifup: accept short option completions too
  * timeout: fallback to _parse_usage from _parse_help
  * test_wget: test --s instead of --h
  * test_lsusb: xfail with unparseable --help
  * test: expect failures for various completions without useful
  - -help
  * test: support xfail in our markers like skipif, use it a lot
  * test: add Alpine Linux container, allow failures for now
  * iconv: weed out ... from encoding completions
  * test_iconv: add basic file completion test
  * test_iconv: skip option completion if --help fails
  * test_getconf: skip if -a doesn't output any POSIX_V*
  * test_feh, test_makepkg: invoke grep as "command grep"
  * test: generalize check whether we're being run in a container
  * tar: simplify locating tarball from command line
  * pkg_delete: don't limit to FreeBSD
  * test: reformat test_chromium_browser.py source
  * test: set up BASH_COMPLETION_COMPAT_DIR in bashrc (only)
  * test: more thorough system location interference avoidance
  * test: bashrc comment and whitespace tweaks
  * build: makefile whitespace tweaks
  * build: really reset return value before completions check
  * build: simplify symlink setup
  * tar: add missing bsdtar, gtar, and star symlinks
  * README: use light gray badges for unknown versions
  * README: link to cygwin package
  * ri: hush some warnings
  * unrar: complete on *.exe (#337)
  * chromium-browser: Add support for .mhtml files
  * screen: complete first arg with serial devices
  * gcc: support new --completion option (#222)
  * unzip, zipinfo: complete *.aab (#340)
  * cppcheck: Remove deprecated option 'posix'  for '--std='
- Remove gcc-564d068.patch and sh-script-completion-boo977336.patch
  as these are implemented upstream.
- Update to version 2.9:
  * dpkg-source: Add --before-build --after-build --commit, and
  - -print-format
  * xm: Deprecate completion for obsolete command (#284)
  * _filedir_xspec: Fallback to suggesting all files if requested
    (#260)
  * tar: Support completions for zstd compression extensions (#255)
  * dpkg: List held packages (#250)
  * cvs: Add completion for the log command
  * unzip, zipinfo: Associate with *.xar (eXist-db application
    package) (#257)
  * mplayer: Associate with *.w64
  * okular: Added support for xz-compressed files.
  * _xspecs: Declare as global on bash >= 4.2
  * test: Increase expect pty to 160 columns
  * test: avoid interrupting magic mark output
  * 7z: add .msi support
  * tshark: speed up tshark -O completion
  * tshark: fix completion of -Xlua_script option
  * tshark: Support preferences (-o) completion with memoization
  * test: fix misinterpretation of completion output in tests
  * test: fix flake8 complaints about unused imports
  * conftest: fix RemovedInPytest4Warning due to use of
    node.get_marker
  * chromium-browser: consider chrome and chromium as aliases
  * tshark: support .gz and .cap files for -r expansion
  * tshark: prevent a single-character file from breaking -G
    completion
  * tshark: update -T and -t completions
  * man: Fix completion when failglob option is enabled (#225)
  * mplayer: Add common supported module music formats
  * _longopt: pick first long option on a line, not last
  * *: avoid shellcheck SC1007 and SC1010
  * 7z: add some TODO notes on parsing "i" output for extensions
  * ssh: make -o protocol completion less hardcoded
  * ssh: make option completion case insensitive
  * ssh: fix suboption completion with combined -*o
  * xvnc4viewer: code cleanups
  * doc/testing: remove lots of legacy info, add some new
  * CONTRIBUTING: add upstream vs bash-completion considerations
  * CONTRIBUTING: note runLint and run-shellcheck
  * __parse_options, 7z: avoid herestrings
  * arp, ccze, ifstat, inotifywait, makepkg: invoke sed with "command"
  * shellcheck: disable bunch of warnings when in "-S warning" mode
  * test: move default shell option from run-shellcheck to
    .shellcheckrc
  * test: make runLint search for herestrings
  * tar, valgrind: avoid some herestrings
  * travis: run shellcheck on bash_completion.sh.in too
  * travis: fail on shellcheck errors
  * make: quote eval array definitions to work around shellcheck
    SC1036 bug
  * test: add make -C test case
  * *: shellcheck error fixes
  * _included_ssh_config_files: store found included files in an array
  * _included_ssh_config_files: doc grammar fixes
  * test: add invoke-rc.d test case for not repeating already given
    options
  * ebtables: improve existing table arg parsing
  * test: add script to run shellcheck, run it in Travis, allowing
    failure for now
  * iptables: improve existing table arg parsing
  * test: shorten long gdb test core file name so tar doesn't croak on
    it
  * AUTHORS: remove unrelated project association from my entry
  * apt-get: protect source against regex specials
  * mypy, mysql, xmms: don't complete unknown split long option args
  * synclient: remove unused local variable "split"
  * test: adjust _get_comp_words_by_ref test to changed error output
  * apt-cache: protect showsrc against regex specials
  * test: improve tshark -O arg completion test
  * tshark: ignore stderr when parsing -G, -L, and -h output
  * *: error output consistency, use bash_completion prefix
  * _upvar: deprecate in favor of _upvars
  * *: add missing "ex: filetype=sh"
  * phing: fix getting just a tab for options on CentOS 6
  * phing: don't complete -l with files
  * various: apply file vs dir special cases also when invoked with
    full path
  * *: whitespace tweaks
  * ssh: don't offer protocol v1 specific options if it's not
    supported
  * test: add some gdb non-core files
  * _parse_help: look for long options somewhat more eagerly
  * gdb: relax core filename pattern
  * test/tools: fix exit status incrementation
  * *: arithmetic expression related cleanups
  * test/tools: run all tools, don't stop at first failure
  * test: check for perltidy errors and warnings
  * *: format Perl code with perltidy
  * *: format Python code with black
  * .dir-locals.el: use flycheck-sh-bash-args
  * valgrind: look up tools from libexec dirs too
  * *: make _parse_usage fallbacks more concise
  * svn, svk, wget: use _iconv_charsets
  * *: spelling fixes
  * msynctool: code cleanups
  * *: remove whitespace after redirections
  * *: remove spaces immediately within $()
  * bzip2: recognize *.tbz2 as bzipped
  * modprobe: module parameter boolean values
  * ping, tracepath: parse options primarily with _parse_help
  * ulimit: new completion
  * shellcheck: new completion
  * dnssec-keygen: new completion
  * modprobe: append = to module parameter completions
  * test: include test_unit_longopt.py in dist
  * test: add some _longopt unit tests
  * _longopt: simplify regex, use printf instead of echo, drop
    unnecessary sort
  * nsupdate: new completion
  * _longopt: don't complete --no-* with file/dirname arg
  * copyright: add 2019
  * pytest: complete --pythonwarnings/-W arg
  * python: make warning action list reusable
  * test: use pytest-xdist
  * extra: add git pre-push hook for triggering Docker Hub builds
  * post-commit: trigger on test/requirements.txt too
  * pytest: complete pytest-xdist --dist, --numprocesses, and
  - -rsyncdir
  * test: remove no longer needed completion/*.exp
  * xfreerdp: reinstate support for old versions with dash option
    syntax
  * test: rewrite "generate" in Python, fix trailing backslash in
    EXTRA_DIST
  * test: sort t/Makefile.am EXTRA_DIST in C locale
  * ssh: support RemoteCommand and SyslogFacility options
  * test: Expect failure for chown all users test as non-root
  * test: Fix declare test case with bash 5.0
  * adb: Deprecate in favor of one shipped with the Android SDK
  * xfreerdp: Update for more modern xfreerdp
  * jsonschema: New completion
  * test: Remove unnecessary ri xfail
  * test: Clean up man tmp dir
  * .gitignore: Add .python-version (for pyenv)
  * test: Remove unnecessary autouse=True from fixtures
  * ifstat: Make work with iproute2 version
  * iperf, iperf3: Add some option arg (non-)completions
  * test: Fix test generation wrt results checking improvements
  * ifstat: New completion
  * __parse_options: Avoid non-zero exit status
  * test: Refactor/improve completion results checking
  * test: Match Python's default locale unaware sort in bash setup
  * test: Rename completion.line to .output
  * test: Add man failglob test case
  * test: Add pre_cmds support for completion fixture
  * inotifywatch: New completion, common with inotifywait
  * inotifywait: Fix -e completion with BSD sed
  * inotifywait: Avoid some false positive event names
  * test: extend _ip_addresses unit tests some
  * _ip_addresses: Avoid completing ipv4 ones with -6
  * inotifywait: New completion
  * test: Mark some xfails based on if in docker instead of in CI
  * test: Skip ifup options test if it doesn't grok --help, not in CI
  * test: Clean up and docker-ignore __pycache__ dirs
  * build: Include test/t in dist tarball
  * test/t: Avoid trailing backslash in Makefile.am's to appease
    automake
  * test: Remove some no longer used old test suite code
  * _xspecs: Simplify bash version check
  * chmod: Fix "-" completion
  * sysctl: Treat -f as alias for -p/--load
  * .gitignore: Add pytestdebug.log
  * chmod: Fix file completion after modes starting with a dash
  * _count_args: Add 3rd arg for treating option-like things as args
  * test: Fix _count_args test_7 to test intended case
  * pydocstyle: New completion
  * Travis: Remove unused PYTEST env var
  * doc: Note email issues gateway
  * tcpdump: Various option and their arg completion updates
  * test: Fix arp CI (non)expectations, remove redundant test case
  * test: Be more consistent with "CI" env var examination and xfails
  * arp: New completion, somewhat incomplete
  * test: Expect failure in gkrellm if there's no X display
  * doc: Update docs on generating simple tests
  * doc: Some test dependency doc updates
  * test: Add requirements.txt for installing dependencies
  * grpck: Parse options with _parse_help, falling back to
    _parse_usage
  * grpck: Add --root/-R arg completion
  * test suite: Ignore _scp_path_esc in env for ssh-copy-id
  * ssh-copy-id: Add -i and -o arg (non-)completions
  * tar: Clean up some redundant code
  * cancel: Split long line
  * cancel: Add some option arg (non-)completions
  * locale-gen: New completion
  * makepkg: Don't apply to other than Slackware makepkg
  * test: Allow unknowns options in makepkg option completion
  * makepkg: Use _parse_help instead of hardcoding option list
  * mypy: New completion
  * op: New completion
  * hunspell: New completion
  * xmllint: Improve --encode, --pretty, and --xpath arg
    (non-)completions
  * test: Remove leftover completion/ls.exp
  * gcc: Add g++, gcc, gccgo, and gfortran *-[568] aliases
  * perlcritic: New completion
  * gnome-screenshot: New completion
  * isort: New completion
  * freeciv: Option and arg completion updates
  * freeciv-gtk2: Install for freeciv and freeciv-gtk3, rename to
    freeciv
  * mplayer etc: Complete on *.crdownload partial downloads in
    addition to *.part
  * chromium-browser, google-chrome*: New non-xspec completion
  * firefox etc: New non-xspec completion
  * Merge branch 'master' into wip-pexpect
  * nc: Add some more option (non-)completions
  * test: Mark MANPATH without leading/trailing colons test an xfail
    on CI CentOS 6
  * test: Remove kill, killall remnants
  * test: Make case specific env entries shell code, not escaped
  * Merge branch 'master' into wip-pexpect
  * unzip, zipinfo: Associate with *.whl
  * __load_completion: Avoid unnecessary lookups from nonexistent dirs
  * Merge branch 'master' into wip-pexpect
  * gcc: Add g++, gcc, gccgo, and gfortran *-7 aliases
  * test: Use test_unit_* prefix for unit tests, to avoid name clashes
  * test: Support setting cmd=None to require no command, for unit
    tests
  * test: Misc test suite fixes
  * test: Fix jq and scrub skipif commands
  * test: Don't require complete marker on test methods
  * test: Add support for per-test env modifications
  * test: Use more conventional Python file names for tests
  * test: Sort completion results in Python for ease of use in Python
    tests
  * test: Allow __load_completion to fail
  * test: chdir to fixtures dir in Python as well
  * test: Mark xfreerdp as expected failure for now
  * test: Replace + with Plus in test class names
  * test: Implement load_completion_for using assert_bash_exec
  * test: Add ability to selectively ignore diffs in environment
  * test: Fixture reorganization
  * test: Pass through $HOME and $DISPLAY to test bash
  * test: Log pexpect interaction to $BASHCOMP_TEST_LOGFILE if set
  * test: Rename BASHCOMP_* test env variables to BASHCOMP_TEST_*
  * test: Add python3 test case
  * test: Add class level skipif based on bash exec result
  * test: Include command name in test class name, use numbered test
    method names
  * test: Fix some regressions introduced in recent test conversions
  * test: Add support for running test case in a specified dir
  * test: Add support for skipping individual tests based on shell
    command status
  * test: Make test base work with Python 3.3+
  * test: Add some iperf, iperf3 and xmodmap test cases
  * xmodmap: Use _parse_help instead of hardcoded option list
  * iperf: Improve client/server specific option parsing
  * iperf: Install for iperf3 too
  * iperf: Add g/G to --format completions
  * xmodmap: Use _parse_help instead of hardcoded option list
  * iperf: Improve client/server specific option parsing
  * iperf: Install for iperf3 too
  * iperf: Add g/G to --format completions
  * test: Use /root/.local/bin/pytest on ubuntu14 by default
  * test: Add generated test files to t/Makefile.am automatically
  * test: Add new test files to EXTRA_DIST
  * test: Use /root/.local/bin/pytest on centos6 by default
  * test: Use make pytest docker executable env-configurable, default
    pytest-3
  * test: Update generate for pytest+pexpect
  * test: Convert majority of test cases to pytest+pexpect
  * tox: Fall back to --listenvs for env list if --listenvs-all fails
  * git-post-commit: Avoid some error trash when HEAD is not a
    symbolic ref
  * test: Add pylint-3 test case
  * test: Limit number of pylint option completions
  * pydoc, pylint: Determine python2/3 based on command basename only
  * pylint: Bring -f/--format arg completion up to date with pylint
    1.9.2
  * pylint: Implement comma separated --confidence arg completion
  * test: Fix buffer size option listing in run --help
  * test: Bump expect's match_max to 20000 by default
  * test: Run docker tests with --verbose
  * _services: Try systemctl list-unit-files if systemctl list-units
    fails
  * extra/git-post-commit.sh: Add git post-commit Docker Hub trigger
    hook
  * gpgv: New completion
  * pydoc, pylint: Skip module completion if current looks like a path
  * travis: Run ubuntu14/bsd with no network
  * travis: Split long lines in script
  * test: Limit number of wget option completions to avoid unresolved
    result
  * test: Mark flake8 untested if it seems broken
  * pylint: Option arg completion improvements
  * tshark: Get available interfaces from -D output
  * ngrep: Add "any" to -d arg completions
  * fio: New completion
  * test: Fix iwspy test case
  * uscan: Use _parse_help instead of hardcoded option list
  * urlsnarf: Add -p arg completion
  * tracepath: Add -m and -p arg non-completions
  * tracepath: Actually use our separate completion instead of
    _known_hosts
  * test: Skip jq option completion test if its --help doesn't list
    them
  * xdg-settings: Make help parsing work on BSD
  * test: Support running with local BSD binaries, do it w/ ubuntu14
    in CI
  * jq, sqlite3: Protect against negative array subscripts
  * sudo: Improve long option arg handling
  * sysctl: Recognize --pattern/-r and --load options
  * test: Add sysctl option parsing test case
  * sudo: Parse options from help/usage output, add some long option
    support
  * strace: Use _parse_help instead of hardcoded option list
  * sshow: Add -p arg completion
  * sqlite3: Add some option arg (non-)completions
  * tune2fs: Update -o/-O argument lists
  * jq: New completion
  * reportbug: Run _parse_help and apt-cache more selectively
  * querybts: Use _parse_help, not hardcoded option list, misc
    improvements
  * pyvenv: Support versioned 3.6-3.8 executables
  * passwd: Try _parse_help before _parse_usage to parse options
  * profile.d: Avoid tested variable values being confused as [ ]
    operators
  * cryptsetup: Add some option arg (non-)completions
  * cryptsetup, nc, sh: Skip option args when counting arguments
  * modinfo: Fall back to _parse_usage if _parse_help yields no
    results
  * mysql, mysqladmin: Complete --ssl-{ca,cert,key} option arg
  * mysqladmin: Reuse --default-character-set completion from mysql
  * modinfo: Use _parse_help instead of hardcoded option list
  * minicom: Use _parse_help instead of hardcoded option list
  * mplayer: Associate with *.S[3T]M, *.med, *.MED
  * completions/Makefile.am: Use install-data-hook, not install-data-
    local
  * ifup etc: Add option and option argument completion
  * _count_args: Add support for not counting specified option args
  * ifquery: New ifup alias completion
  * ngrep, tshark: Complete on *.pcapng too
  * rpm: Complete --licensefiles with -q
  * pytest: Rename from py.test to follow upstream recommended name
  * README: Add instructions for overriding completions system wide
  * README: Note $BASH_COMPLETION_USER_DIR
  * test: Mark psql etc test cases untested if --help doesn't work
  * aclocal, automake: Support versioned 1.16 executables
  * __load_completion: Avoid bad array subscript on "commands" ending
    with slash
  * lzma: Use _parse_help instead of hardcoded option list
  * test: Run perlcritic and flake8 on perl and python helpers in
    Travis
  * build: Improve cleanup of test/log and test/tmp dirs
  * pkg-config: Complete on *.pc files
  * build: Use AC_PROG_SED to locate sed
  * build: Do cmake, pc, and profile variable replacements in Makefile
  * README: Add Q/A on overriding a completion, modernize local
    install answer
  * json_xs: New completion
  * chmod: New completion
  * iperf, nc: Include IPv6 addresses in bind address completions
  * links: Major rework, parse options from --help, add option arg
    completion
  * _ip_addresses: Add option to complete all/v4/v6 addresses, add
    unit test
  * wget: Remove nonexistent arg to _ip_addresses
  * _filedir: Drop unnecessary evals
  * iconv: Split charset completion to _iconv_charsets, add test case
  * links: Install completion for links2 too
  * xgamma: Comment spelling fix
  * lftp: handle -s
  * test: Skip scrub -p test when its --help doesn't list available
    patterns
  * ecryptfs-migrate-home: New completion
  * scrub: New completion
  * ether-wake: Install for etherwake as well
  * *: Support completing arg of last bundled short option
  * dselect: Parse options with _parse_help
  * dhclient: Add some option arg (non-)completions
  * dhclient: Parse options with _parse_usage
  * chage, chpasswd: Add -R/--root arg completion
  * reportbug: Add bunch of option arg (non-)completions
  * .dir-locals.el: Set -O extglob for flycheck bash checks
  * mount, umount: Deprecate on Linux in favor of util-linux >= 2.28
    ones
  * _known_hosts_real: Reimplement known hosts file parsing in pure
    bash
  * test: Add comment line to fixtures/_known_hosts_real/known_hosts
  * ssh: Complete all *File option args with _filedir
  * README: Point Debian and openSUSE badges towards unstable and
    Tumbleweed
  * README: Link to various distro packages
  * apt-get: Add -h/-v/-o non-completions
  * apt-get: Sync option list with apt 1.5.1
  * apt-get: Simplify -t and friends completion, support Ubuntu
  * apt-get: Add indextargets to list of suggested commands
  * apt-get: Complete install package=versions
  * ssh: Sync config option lists with OpenSSH 7.5p1, add some value
    completions
  * ssh: Sync query type list with OpenSSH 7.5p1
  * ssh: Order various switch cases closer to alphabetical
  * completions/Makefile: Fix check-local in VPATH builds
  * _filedir: Refactor to remove heredoc-dependent loop
  * gccgo: Add as a GCC completion target (#227)
  * xrandr: match the output name exactly for --mode
* Fri Apr 26 2019 Dr. Werner Fink <werner@suse.de>
- Add patch gcc-564d068.patch from pull request 564d068 of
  Martin to upstream of bash-completion
* Fri Mar 29 2019 Martin Wilck <mwilck@suse.com>
- Removed bts completions (upcoming devscript package contains a
  more recent one).
* Mon Oct 22 2018 Dr. Werner Fink <werner@suse.de>
- Modify patch PS1-completion-boo903362.patch to make it work with
  mksh as well (boo#1104531)
* Thu Aug  2 2018 antoine.belvire@opensuse.org
- Update to version 2.8:
  * Comma separated opt arg completion improvements
  * Protect _known_hosts_real from user input treated as options
  * Protect shopt reset from non-default $IFS
  * Add support for .lz4 extension to file-roller (#158)
  * Add support for .lzo extension (--lzop) to tar (#155)
  * Bump copyright years to -2018
  * README.md: Whitespace cleanup
  * Whitespace
  * __expand_tilde_by_ref: Eval tilde expansion only, simplify
  * __load_completion: Code cleanup
  * __load_completion: Load "xspec" completions dynamically too
  * _avaiable_interfaces: Get rid of eval
  * _expand: Reuse __expand_tilde_by_ref and _tilde logic, clean up
  * _known_hosts_real: Add option to filter IPv4 and IPv6 addresses
  * _known_hosts_real: Document -a better
  * alias: Fix completion followed by = (#146)
  * apt-get: Complete *.deb on install if argument contains a slash
  * aptitude-curses: Use aptitude completion
  * aptitude: Add keep to commands list (Debian: #867587)
  * bzip2, gzip, and other compressors: Use _tilde instead of _expand
  * ccze: New completion
  * cryptsetup: Update option lists
  * curl: Fix -x etc option argument hostname completion
  * dd, find, gcc: Remove unnecessary tilde expansion
  * dd: Omit space only when offering one completion ending with =
  * dpkg-query: Fix -W/--show completion
  * dpkg: Add -V/--verify arg completion
  * dpkg: Complete --vextract on deb files
  * dpkg: Fix man page section in comment
  * ebtables: new completion (#150)
  * flake8: Various option arg completion improvements
  * geoiplookup: New completion
  * getconf: New completion
  * groupdel: Parse and handle long options
  * info, man, rsync: Defer _expand invocation
  * iptables: Avoid stderr trashing when invoked as non-root
  * iptables: Parse options from --help output
  * iptables: Use invoked command instead of hardcoded "iptables"
  * java: Complete *.war
  * kldunload: Increase robustness of compgen filters (#185)
  * kldunload: Show modules with digits
  * ktutil: Don't leak i and command environment variables
  * lftp: Support ~/.local/... bookmark location (#144)
  * lowriter,localc etc: Use corresponding oo* completions
  * lspci: New completion
  * lsscsi: New completion
  * lsusb: New completion
  * make-changelog.py: Use python3
  * make: Pass script to sed as parameter instead of using process substitution
  * man: Don't use $MANPATH directly (#161)
  * mkdir: Complete files without appending space
  * mkdir: Complete on files in addition to dirs
  * mplayer: Disable user config when parsing options
  * nproc: New completion
  * oggdec: New completion
  * openssl: Add completion for the genpkey, pkey, pkeyparam, and pkeyutl commands
  * perltidy: New completion
  * ping*,ssh,scp,sftp,tracepath6: Filter IPv4/IPv6 literal addresses
  * pv: New completion
  * pycodestyle: New completion
  * pylint: Install for pylint-2 and pylint-3 too
  * pylint: Invoke python3 to search for modules if command contains 3
  * python: Support completing dotted module hierarchies
  * radvdump: New completion
  * reportbug: Add -A/--attach arg completion
  * reportbug: Don't hardcode option lists, split option args at =
  * rfkill: Rename to _rfkill to avoid conflict with util-linux >= 2.31
  * ri: Fix integrated ri 1.8 class completion
  * ssh,ssh-add,ssh-keygen: Complete pkcs11 options with *.so
  * ssh-keygen: Add -E arg completion
  * ssh: Add -J/ProxyJump completion
  * ssh: Declare $prefix closer to use
  * test suite: Add basic hid2hci and munin-node-configure test cases
  * test suite: Add bunch of man and MANPATH test cases
  * test suite: Add bunch of missing basic test cases
  * test suite: Add info and pinfo option test cases
  * test suite: Drop no longer needed fedoradev /usr/bin/which workaround
  * test suite: Enable wine in ubuntu14
  * test suite: Install aptitude in ubuntu14 container
  * test suite: Limit amount of info and pinfo test output
  * test suite: Limit amount of output from process name completion
  * test suite: Limit number of screen -T completion matches
  * test suite: Make man test subject names less generic
  * test suite: Skip fedoradev GPG checks at least for now
  * test suite: Some more mplayer and mencoder coverage
  * test suite: Support overriding default match buffer size (#141)
  * test suite: man cleanup
  * test/docker: Tweak work dir, add bash as default cmd
  * test/unit: Whitespace tweaks
  * test: Add "postconf -" test case
  * test: Add assert_complete_homedir, use in dpkg and ls
  * test: Add files to test older ri with
  * test: Add some _expand unit tests
  * test: Add some comments regarding bash init in library.exp
  * test: Fix getting username in non-login shells
  * test: Ignore duplicates in find_unique_completion_pair list
  * test: Remove things moved to library.exp from bashrc
  * test: Try to skip postconf variable test on broken postfix configs altogether
  * test: Use prebuilt docker hub bash-completion images
  * test: Work around broken centos/fedora postfix config in non-IPv6 setup
  * test: dpkg,ls,_tilde: Skip gracefully if no uniq user for completion is found
  * test: run bash with --norc to avoid system bashrc
  * tox: Avoid stderr spewage when -e invoked without tox.ini
  * tox: Complete comma separated -e arguments
  * tox: Include ALL in -e completions
  * tox: New completion (#163)
  * tox: Remove spurious executable bits
  * unzip, zipinfo: Associate *.gar (#165)
  * uscan: Don't leak cword and words environment variables
  * vpnc: Add some option argument (non)completions
  * vpnc: Improve config completions
  * xdg-mime,xdg-settings: Fix inclusion in tarball
  * xdg-mime: New completion
  * xdg-settings: New completion
  * xine etc, ogg123, mplayer -audiofile: Associate with *.oga
  * xm: Don't leak args and commands environment variables
* Tue Apr 24 2018 werner@suse.de
- Add patch bash-completion-2.7-unRAR-remove.patch that is due legal
  issue the unRAR part of 7z had been removed (boo#1077978, boo#1090515)
* Tue Apr  3 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Mon Dec 18 2017 sbrabec@suse.com
- Remove rfkill conflicting with util-linux-2.31.
* Tue Jul  4 2017 werner@suse.de
- Update to version 2.7
  * Makefile: update default compatdir (#132)
  * Make user completion file configurable, disable in tests
  * test suite: Generalize xspec completion install check
  * pyflakes: Remove redundant xspec completion
  * test suite: Fix __expand_tilde_by_ref test expectation output
  * pdfunite: New *.pdf completion
  + bash-completion (2.6)
  * Add missing sidedoor to .gitignore (#114)
  * test suite: Mark expected centos6 CI _filedir failures as such
  * Expose version in BASH_COMPLETION_VERSINFO, use it in profile.d
    script
  * test suite: Skip an expected make test case failure in centos6 CI
  * test suite: Fix ifdown and ifup CI test skipping
  * test suite: Ignore env var pulled in by use of scp in tests
  * test suite: If colon trim doesn't do anything, trim as usual
  * tar: Comment spelling fixes
  * test suite: Mark dpkg -L test case untested if no packages
    installed
  * test suite: Cosmetic tweaks
  * dpkg: Fix dpkg -i home dir completion
  * test suite: Improve ls home dir test descriptions
  * python: Split module completion to separate helper
  * micropython: New completion, aliased from python
  * test suite: Add Python module completion test case
  * python: Fix traceback avoidance on module completion error
  * openssl: Parse available digests from dgst -h
  * openssl: Add sha2 commands
  * gm: New completion, commands only for now
  * (test suite): Test screen -T completions
  * (test suite): Set TERM to dumb, not dummy
  * Revert "(test suite): Fix alias and cd cursor position tests"
  * mplayer: Remove duplicate *.m4a and *.m4v associations
  * mplayer, xine, etc: Associate *.mp4a and *.mp4v
  * xine etc: Fix *.m4a association
  * bind: Add option and argument (non-)completions
  * _user_at_host: Set nospace only when completing username part
  * _user_at_host: Append @ suffix to username part completions
  * man: Don't check OSTYPE or GNU userland, just enable on all
    systems
  * (test suite): Set dcop result to untested if dcop server is not
    running
  * (test suite): Don't insist on loading all completions dynamically
  * _configured_interfaces: Parse from /etc/network/interfaces.d/* on
    Debian
  * py.test: New completion
  * oowriter: Associate with *.pdf
  * Don't define BASH_COMPLETION_COMPAT_DIR
  * ri: Add option and arg completions
  * (test suite): Add our own dummy ri test fixture
  * (test suite): Info test needs docs, don't exclude from CentOS
  * (test suite): Fix CentOS 6 tcllib setup
  * (test suite): Simplify renice test, fix with only one completion
  * (test suite): Don't assume configured interfaces in CI setups
  * Don't offer * as configured interface when there are none
  * (test suite): Add basic CentOS 6 container for bash 4.1 coverage
  * (test suite): Ignore runtime loaded env function changes
  * (test suite): Add mailman bin dir to PATH for arch test
  * arch: Parse options from --help
  * (test suite): Load tested completions dynamically
  * (test suite): Accept non-whitespace single word in
    assert_complete_any
  * (test suite): Avoid interference from user and system dirs (#87)
  * (test suite): Install some things N/A in ubuntu14 to fedoradev
  * (test suite): Add unrar to ubuntu14 container
  * (test suite): Fix alias and cd cursor position tests
  * (test suite): Add basic alpine test case
  * alpine: Parse opts from -h output, add some opt arg completions
  * (test suite): Install jshint globally in ubuntu14
  * (test suite): Add mailman bin dir to PATH for some mailman tools
  * (test suite): Install jshint to ubuntu14 container with npm
  * unshunt: Parse options from --help
  * (test suite): Test lsof on ubuntu14
  * (test suite): Add basic hping3 test case
  * (test suite): Add our ./configure to PATH to test it, test opts
  * (test suite): Add bunch of packages to ubuntu14 container
  * (test suite): Ensure /usr/(local/)games is in $PATH
  * (test suite): Fix perl -d* test cases with no Devel::* installed
  * (test suite): curl has lots of options, add more test prefix
  * (test suite): Fix tar test case for ones having --owner-map
  * (test suite): Unsupport various kill, renice cases if ps is N/A
  * (test suite): Make chkconfig test behave better in container
  * (test suite): Don't assume mounted filesystems in quota* tests
  * newlist: Parse options from --help, add some arg non-completions
  * (test suite): Delete trailing whitespace
  * (test suite): Don't assume lists set up in newlist test cases
  * (docker): Pull in missing fedoradev xvfb-run which dependency
  * mr: Avoid stderr trash and test suite failure if man is N/A
  * (test suite): Fix mmsitepass completion test
  * tshark -G: Avoid stderr noise when running as superuser
  * (docker): Run completion tests with xvfb-run, e.g. for gkrellm
  * ssh-keygen: Make option parsing work with OpenSSH < 7
  * synclient, udevadm: Avoid use of posix char classes for awk
  * test suite: Add WIP Fedora dev config
  * Travis: Switch tests to docker, update to Ubuntu 14
  * xv: Associate with *.j2c, *.j2k, *.jp2, *.jpf, and *.jpg2 (Debian:
    [#859774])
  * eog: Associate with *.j2c and *.jpg2
  * Bump copyright years
  * xine etc: Associate uppercase *.WM[AV]
  * mplayer: Associate *.weba (#112)
  * xine etc: Associate *.webm and *.weba (#112)
- Modify patches
  * FOO-dir-completion-boo905348.patch
  * PS1-completion-boo903362.patch
  * backtick-completion-boo940835.patch
  * backticks-bsc963140.patch
  * bash-completion-2.4.patch
  * bash-completion.changes
  * bash-completion.spec
  * ls-completion-boo889319.patch
  * respect-variables-boo940837.patch
  * rm-completion-smart-boo958462.patch
  * sh-script-completion-boo977336.patch
* Tue May 30 2017 nico.kruber@gmail.com
- Update to version 2.5
  * Support for python gui source files (#91)
  * mr: New completion
  * ssh-keygen: support ed25519 keys (#79)
  * Add sidedoor to _ssh() completion (#106)
  * .ipa is just a zip file and we should let unzip handle it (#71)
  * ant: parse targets in imported buildfiles (#84)
  * Add more tests for ccache
  * ccache: fix completing compiler's flags
  * test suite: Add java/javac non-completion fixture
  * javac: Complete -cp like -classpath
  * travis: Skip bluez and nis for now due to post-install script
    issues
  * test/config/*: Delete trailing whitespace
  * (test suite): Avoid loading user's ~/.bash_completion, fixes #87
  * ip: Recognize a as alias for address and l for link
  * ip: Recognize address in addition to addr
  * mr: Disable "clean" test case, command N/A before mr 1.20141023
  * ssh-keygen: Parse switches with _parse_usage, not _parse_help
  * mplayer: Associate with *.mjpg, *.mjpeg (Debian: #837779)
  * dd: Sync completions with coreutils 8.24
  * travis: Add mr
  * perl: Remove full path to cat in PERLDOC_PAGER call
  * deja-dup: New completion
  * CONTRIBUTING: Reorder sections
  * *: Move indentation settings to .editorconfig
  * make: Declare _make_target_extract_script like other functions
  * Travis: zopfli is AWOL?
  * *: Whitespace fixes
  * Minor edits to README.md (mostly formatting) (#110)
  * Fix bug in 'make' completion when using BSD sed (#108)
  * Add support for Include in ssh config (#70) (#80)
- adapt LVM-completion-bsc946875.patch
* Thu Dec 15 2016 werner@suse.de
- Detect if the completions for mount/umount have to be removed
  for modern util-linux package but without using suse_version
* Thu Dec 15 2016 werner@suse.de
- Fix cut&paste error in final ls completion
* Wed Dec 14 2016 werner@suse.de
- Add patch tar-completion.patch to allow mixed options with long
  and short options (boo#1012212)
* Wed Dec 14 2016 werner@suse.de
- Change upstream home to https://github.com/scop/bash-completion
- Update to version 2.4
  * xetex, xelatex, luatex, lualatex: Associate with tex files
  * Support pod document files for perldoc (#39)
  * tipc: add tipc completions
  * rpm: Offer --filetriggers with -q
  * javadoc: Add bunch of option arg (non)completions
  * lrzip: Add -m arg noncompletion
  * pypy*: Add basic --jit arg completion
  * pypy3: Alias to python
  * hcitool,svcadm,tar: Spelling fixes
  * tipc: Invoke ls with "command"
  * tipc: Indentation fix
  * abook: Parse long options from command including full path
  * pyvenv: New completion
  * chroot: New (generic long options) completion, see #38
  * aptitude: List packages using _apt_cache_packages, fixes #33
  * vncviewer: Cleanup shopt use, drop an eval
  * make: Avoid a grep
  * rpm: Fix --whatenhances arg completion
  * aspell, minicom, mysql: Replace use of ls with printf
  * The BitKeeper completion used the wrong set of commands
  * Completion for python zip archives
  * lvm: pvcreate should be able to use all block devcices
  * lvm: fix all commands that should get all PVs
  * tar: Detect GNU/other from --version only once per session
  * tar: Remove unused variable
  * tar: Fix GNU tar help output parsing regex, fixes #15
  * tar: Don't write to /tmp/jetel
  * python: Simplify code
  * python: Complete all files also after -m
  * python: Don't offer options after -c
  * python: Complete all files only if -c is before current word
  * unzip, zipinfo: Complete on *.pyz
  * _lvm: using a single-pattern case and invoking function according
    to words[1]
  * lvm: _lvm_count_args parameter must be quoted in order to failglob
    not to complain
  * gendiff: Quoting suffix pattern to avoid triggering failglob
  * ssh-add, ssh-keygen: -? needs to be quoted under failglob (Alioth:
    [#314709])
  * Refactor bts and uscan, since they use common functions
  * uscan: New completion, thanks to Federico Ceratto
  * bts: New completion, thanks to Federico Ceratto.
  * nmcli completion was integrated upstream
  * ssh-add, ssh-keygen: -? needs to be quoted under failglob (take 2)
    (Alioth: #314709)
  * umount: Fix mount points escaping/unescaping with Bash-4.3
  * slapt-src: Handle --config=FILE option properly
  * sbopkg, slapt-{get,src}: expand tilde in config file name
  * slapt-{get,src}: Fix issue with sed not being able to handle some
    characters
  * slapt-src: split options from their arguments
  * psql: Tell psql to not load .psqlrc as it may change output format
    (Alioth: #314636)
  * mplayer: -dvd-devices takes dvd devices, dirs and .iso files as
    argument
  * 7z: Improve completion
  * f77, f95: Use the same completion as for g77, g95 if they are
    links to gfortran
  * make: Use only posix basic regexps with sed (Alioth: #314345)
  * perl: -d/-dt option argument is optional (Alioth: #314242)
  * Add config for cmake to bash-completion.
  * kcov: Add new sort types, complete --replace-src-path arguments
  * feh: Add new sort type
  * man: Use -w instead of --path
  * chronyc: Update help text parsing
  * chronyc: Add missing subcommands
  * chronyc: Add -6 option
  * minicom: Recognize user ~/.minirc.* as config files
  * rpmbuild: Complete *.spec on --clean (RedHat: #1132959)
  * tar: rework the completion completely
  * portsnap: New completion.
  * modprobe: fix params with multi-line descriptions
  * gdb: support --args style completion (Alioth: #314664)
  * make: Fix basic regex for portability (Alioth: #314345)
  * gnokii: New completion
  * xmllint, xmlwf, xsltproc: Complete on Mallard *.page files
  * pypy: New completion identical to python (Alioth: #314501)
  * make: Don't pick up variables when makefile is reloaded
  * make: Offer hidden targets when it is clear that the user is
    trying to complete one of them
  * make: Fix detection of intermediate targets where make has changed
    its database whitespace
  * make: completion shouldn't be confused by the output of $(info
    confuse: make)
  * zopflipng: New completion
  * ssh: Extract duplicate code to _ssh_configfile
  * gnokii, minicom: Use grep through "command"
  * Update URLs and various instructions to GitHub
  * ssh: Avoid completing commands before hostname
  * chronyc: Parse command args from help output
  * chronyc: Wrap long lines
  * Load completions also from $XDG_DATA_DIRS (RedHat: #1264094)
  * (testsuite) Ignore files generated by complete-ant-cmd.pl
  * scp, sftp: Complete -S on commands
  * scp, sftp: Fix querying ssh options
  * sftp: Add -l arg non-completion
  * ssh-copy-id: Offer only *.pub to -i
  * mpv: Remove mplayer-aliased completion
  * modplug*: Associate *.oct and *.okt
  * rpm: Add --whatenhances/recommends/suggests/supplements and
  - -recommends/supplements completions
  * pgrep, pidof, pkill, pwdx, vmstat: Add support for procps-ng
  * pdftotext: New completion
  * checksec: New completion
  * ssh: Complete HostbasedKeyTypes,HostKeyAlgorithms,KexAlgorithms
    values
  * ssh: Query ciphers and macs from ssh before hardcoded fallback
  * ssh: Add -Q argument completion
  * sysctl: Return early on --help, --version
  * sysctl: Try parsing options from help before usage
  * eog: Complete on *.ppm (RedHat: #1090481)
  * tar: Plug $line var leak
  * tar: Style tweaks
  * bsdtar, tar: Remove symlinks from git, have make create them
  * jshint: New completion
  * gnokii: Include and install it
  * gnokii: Fix completions of options that are prefixes for others
  * gnokii: Drop dead code
  * (testsuite): Add basic gnokii test case
  * gnokii: Various minor and cosmetic fixes
  * Load user completions from $BASH_COMPLETION_USER_DIR/completions
  * synclient: New completion
  * tune2fs: Add missing return in -M arg completion
  * reptyr: Rename file to _reptyr to avoid conflict with upstreamed
    completion
  * dropuser: New completion
  * createuser: New completion
  * createdb, dropdb: Drop -o default, it does not appear to do
    anything good here
  * tshark: Simplify cut usage
  * mcrypt: Simplify -m arg completion
  * strings: Fix -T/--target arg completion with non-English locale
  * chrome, firefox etc: Complete on *.pdf
  * ccache: Add -o/--set-config arg name completion
  * gphoto2: Replace tail with awk
  * gphoto2: Fix split argument handing, and colon treatment in --port
    args
  * Actually install the lz4 completion
  * _pnames: Add -s for producing (possibly) truncated names (RedHat:
    [#744406])
  * (testsuite) Add cd in dir without subdirs or CDPATH test case
  * Protect various compgen invocations from -* leakage (Debian:
    [#766163])
  * pigz, unpigz: Handle *.zz
  * rpmbuild: Complete *.spec on --nobuild
  * mplayer, *xine: Complete on *.mts (Debian: #759219)
  * ant: Support buildfile set in $ANT_ARGS (Alioth: #314735)
  * ant: Don't offer more completions after options that exit
  * 7z, adb: Trivial cleanups
  * python(3): Add -X argument non-completion
  * xsltproc. TODO fix for previous commit
  * xmllint, xmlwf, xsltproc: Complete on *.dbk and *.docbook (Alioth:
    [#314770])
  * xz: Complete -T/--threads argument
  * adb: New completion
  * modprobe: Try parsing help before using hardcoding option list
  * mpv: New completion alias + adjustments for mplayer (Debian:
    [#749115])
  * hostname: New completion
  * nslookup: complete on hosts (Alioth: #314673)
  * eog: Complete on *.pgm (RedHat: #1090481)
  * pngfix: New completion
  * qemu: Fix -balloon arg completion
  * qemu: Apply completion to qemu-kvm/-system-i386/-system-x86_64 too
  * xrandr: Use the invoked command internally, not hardcoded "xrandr"
  * xrandr: Add (some) --setprovider* arg completion support
  * ri: Fix class completion with ri >= 3.
  * ri: Fix colon handling in class completion.
  * flake8: New completion
  * pyflakes: New completion
  * cal,chfn,chsh,dmesg,eject,hexdump,look,newgrp,renice,runuser,su,wr
    ite: Deprecate on Linux in favor of util-linux ones (Debian:
    [#737672])
  * hwclock,ionice,rtcwake: Deprecate in favor of util-linux ones
    (Debian: #737672)
  * ssh-keygen: New completion
  * jpegoptim: New completion
  * ip: Add some addr, addrlabel, and route arg completions
  * aptitude, dpkg: Replace some grep+cuts with awk
  * gcc, lintian, make, pkgadd, slackpkg: grep -> "command grep"
    (Debian: #734095)
  * lintian: Replace some grep+cuts with awk
  * lz4: New completion.
  * optipng: New completion.
  * cppcheck: Include - in --file-list completions.
  * wtf: Look for acronym db from /usr/share/games/bsdgames/acronyms
    too.
  * wtf: Don't offer -f if it was already specified.
  * wtf: Hush stderr when db file doesn't exist.
  * appdata-validate: New completion.
  * timeout: New completion.
  * abook, kldunload: Pre-expand \t instead of relying on sed
    supporting it.
  * dict: Trivial regex cleanup.
  * zopfli: New completion.
  * bzip2, gzip, lzma: Cleanups.
  * 2to3: New completion.
  * file-roller: Reuse unzip's xspec.
  * 7z: New completion.
  * hcitool, rfcomm, ciptool, hciconfig: Don't leak $args.
  * perl: Fix -dt: completion.
  * perl*: Fix handling of relative paths in @INC.
  * wget: Add --accept-regex/--reject-regex/--regex-type arg
    (non)completions.
  * wget: Drop incorrect -nv arg completion.
  * wget: Stop completing after --help/--version.
  * Clean up/compact various globs.
  * cvs: Fix checkout -j non-completion.
  * sh: Complete script arguments with all filenames (Alioth:
    [#314226]).
  * nmcli: Deprecate our completion, upstream has one in 0.9.8.0.
  * cvs rm: Don't filter existing files with -f (RedHat: #949479).
- Drop patches now upstream
  init-completion-boo922758.patch
  pushd-completion-bnc818365.patch
- Rename patches
  bash-completion-2.1.patch becomes bash-completion-2.4.patch
- Port the patches to newer version 2.4
  FOO-dir-completion-boo905348.patch
  LVM-completion-bsc946875.patch
  PS1-completion-boo903362.patch
  backtick-completion-boo940835.patch
  backticks-bsc963140.patch
  ls-completion-boo889319.patch
  respect-variables-boo940837.patch
  rm-completion-smart-boo958462.patch
  sh-script-completion-boo977336.patch
- Only remove completion for umount/mount for older SUSE versions (boo#995045)
* Wed Aug 24 2016 tchvatal@suse.com
- Mark the documentation as noarch
* Wed May 18 2016 sbrabec@suse.com
- Split doc build into a separate spec file. It makes possible to
  build package in two stages and prevent build loop.
* Wed May 18 2016 werner@suse.de
- Split off sub packages devel and doc to avoid dependency cycles
* Wed Apr 27 2016 sbrabec@suse.com
- Remove completions conflicting with util-linux (boo#977259#c3).
* Wed Apr 27 2016 werner@suse.de
- Add patch sh-script-completion-boo977336.patch to make _filedir
  work with COMP_FILEDIR_FALLBACK even if local directries exists
  this is for bug boo##977336
* Wed Apr 27 2016 werner@suse.de
- Add documentation for this packages below to get the reference
  of the e.g. the variable COMP_FILEDIR_FALLBACK (boo#977336)
* Wed Jan 27 2016 werner@suse.de
- Add patch backticks-bsc963140.patch to handle sub commands
  which will be expanded by backticks (bsc#963140)
* Fri Dec 18 2015 werner@suse.de
- Add patch respect-variables-boo940837.patch to avoid completions
  which results in e.g. ls \$HO
- Add patch rm-completion-smart-boo958462.patch to allow completions
  list e.g. rm prefix*.jpg<TAB><TAB>
- Modify patch LVM-completion-bsc946875.patch that is add the
  new patch from Liuhua Wang
* Wed Sep 23 2015 werner@suse.de
- Add patch LVM-completion-bsc946875.patch to make LVM comands
  work even without any scan happen (bsc#946875)
* Thu Aug 13 2015 werner@suse.de
- Add patch backtick-completion-boo940835.patch to allow correct
  backtick completion (boo#940835)
* Wed Aug 12 2015 werner@suse.de
- Correct typo in patch ls-completion-boo889319.patch
* Mon Jun 15 2015 werner@suse.de
- Add patch ls-completion-boo889319.patch to make ls completion
  more smart (boo#889319)
* Wed Mar 18 2015 werner@suse.de
- Port my dollar completion from /etc/profile.d/completion.bash to
  bash_completion which modifies FOO-dir-completion-boo905348.patch
- Avoid negative cword position counter (boo#922758), this adds
  the patch init-completion-boo922758.patch
* Mon Nov 17 2014 werner@suse.de
- Add patch PS1-completion-boo903362.patch to avoid trouble if
  restricted characters of the shell are used in PS1 like
  exclamation mark (boo#903362).
- Add patch FOO-dir-completion-boo905348.patch to expand variables
  which value is actual a directory to avoid excaped dollar sign
  (boo#905348).
* Mon May 13 2013 werner@suse.de
- Add patch pushd-completion-bnc818365.patch for bnc#818365 -- bash
  completion for builtin command "pushd" is missing
* Tue Apr 23 2013 werner@suse.de
- Do not ship NetworManager completion file as it is part of NM
* Tue Apr 23 2013 werner@suse.de
- Update to final 2.1 version
  + See CHANGES for the full list of changes
- Add patch bash-completion-2.1.patch to avoid blanks after during
  file completion (bnc#717151)
* Fri Apr 19 2013 fcrozat@suse.com
- Do no ship udevadm completion file, it is now part of systemd
  package.
* Sat Jul  7 2012 reddwarf@opensuse.org
- Update to final 2.0 version
  + See CHANGES for the full list of changes
- Add pkg-config file
* Mon Jan  9 2012 vuntz@opensuse.org
- Update to version 1.99:
  + New completions: ccache, desktop-file-validate, htop, iperf,
    koji, lzip, nethogs, plague-client, udevadm.
  + Fixes for completions: cc, cppcheck, curl, c++, dequote, dict,
    dmesg, dpkg, lrzip, make, mount, mutt, pidof, removepkg, rpm,
    umount, upgradepkg, vi, wine, xv.
  + See details in CHANGES.
* Wed Nov 30 2011 tiwai@suse.de
- Update to version 1.90:
  - new completions: epdfview, lpr, lpq, mysql, puppet, pkgtool,
    makepkg, rmp2tgz, slapt-get, slapt-src, slackpkg, kcov, feh,
    xgamma, fbi, fbgs sbopkg, a2x, arping, asciidoc, base64, cal,
    chrpath, cppcheck, curl, dmesg, dot, file, gnome-mplayer, gprof,
    hddtemp, host, htpasswd, idn, ionice, jps, lbunzip2, lbzip2,
    lbzcat, prelink, protoc, pwdx, pwgen, reptyr, sum, watch,
    phing, pinfo
  - installed location changed to /usr/share/bash-completion/*
  - see more changes in CHANGES file
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Fri Feb 25 2011 poletti.marco@gmail.com
- Update to version 1.3:
  + Added completions for: badblocks, compgen, crontab, dumpe2fs,
    e2freefrag, e2label, ether-wake, filefrag, gendiff, growisofs,
    hping{,3} (the previous version already completed hping2),
    iftop, ip, iscsiadm, javaws, kid3, lrzip, lsof, mktemp,
    perldoc, portecle, POSIX sh, postgresql,
    sha{,224,256,384,512}sum, sysbench, tune2fs, xfreerdp, xmodmap,
    xm subcommands and xrdb.
  + Improve the completions for: autotools, /etc/init.d/*, ipmitool,
    jar, java, javadoc, MAC address, man, mencoder, mkdir, mplayer,
    okular, pack200, povray, python, rpm, rpmbuild, sqlite3, tar,
    unzip, users/groups (in various contexts), wodim, xine-based
    players and xmllint.
  + Fix the completions for: avahi-browse, IPv6 known hosts,
    kompare, muttrc, p4, povray and ~username (in various
    contexts).
  + Other changes
* Thu Jan 13 2011 vuntz@opensuse.org
- Add bash-completion-fix-service.patch to fix an error created by
  the "service" completion.
* Fri Jan  7 2011 poletti.marco@gmail.com
- Update to version 1.2.
  * Add new completions.
  * Many improvements and fixes to existing completions.
  * Completely drop support for bash < 3.
* Tue Oct 20 2009 poletti.marco@gmail.com
- Update to version 1.1, that supports bash 4.0 better
  * Split many completions in files under contrib/
  * Added new completions
  * Improved existing completions
* Mon Oct  5 2009 vuntz@opensuse.org
- Update to version 1.0 (too many changes to list).
- Remove all our patches except bash-completion-speedup_rpm.patch:
  + bash-completion-bzip2_fix.patch: should be fixed upstream.
  + bash-completion-cd.patch: doesn't seem to be needed.
  + bash-completion-complete_spm.patch: source rpms are now src.rpm
    as far as I can tell, so no need to complete on spm.
  + bash-completion-mount_dir_fix.patch: the fix is not correct. It
    should not be for root only. bnc#386459 should be forwarded
    upstream for a proper fix.
  + bash-completion-no_tilde_expansion.patch: I'm unsure we want
    to diverge there. bnc#386844 should be forwarded upstream for a
    proper fix.
  + bash-completion-readonly_fix.patch: this is now fixed upstream,
    I think.
  + bash-completion-svn_filenames.patch: fixed upstream.
  + bash_completion-rpm_install_complete.patch: I'm really not sure
    the fix is right. bnc#242123 should be forwarded upstream.
- Respin bash-completion-speedup_rpm.patch.
- Remove the git completion: it's now in git itself.
* Tue Nov 11 2008 werner@suse.de
- Make completion for cd command smart (bnc#442827)
* Fri Sep 26 2008 mkoenig@suse.de
- fix problem with readonly vars [bnc#383486]
- speed up rpm completion [bnc#402659]
- complete on .spm [bnc#416901]
* Tue May  6 2008 mkoenig@suse.de
- remove default tilde expansion, as this should be configurable
  by the expand-tilde readline setting, even with bash-completion
  installed [bnc#386844]
* Mon May  5 2008 mkoenig@suse.de
- fix mount completion for root [bnc#386459]
* Tue Apr 22 2008 mkoenig@suse.de
- use -o filenames for svn completion [bnc#382280]
- add empty %%build section
* Fri Jun  1 2007 mkoenig@suse.de
- fix bzip2 completion to handle filenames with spaces [#278608]
* Thu Mar  8 2007 mkoenig@suse.de
- enhance rpm completion [#242123]
* Thu Feb 15 2007 mkoenig@suse.de
- add git-completion
- add %%clean target to specfile
- only install really useful completions by default
* Wed Feb  7 2007 mkoenig@suse.de
- update to version 20060301
  * There were probable bash 3.1 POSIX quote problems if
    UserKnownHostsFile or GlobalKnownHostsFile keywords were used
    inside ssh config files. Fixed.
  * Added new subversion completion implementation
  * Added minicom completion
  * --nodigest and --nosignature options must be set in $nodig and
    $nosig within _rpm_installed_packages() itself, not just set
    in _rpm() before _rpm_installed_packages() is called. This is
    because other completion functions also call
    _rpm_installed_packages().
  * Minor playmidi and timidity additions for .MID(I)
    (capital letters) files.
  * Add kdvi, dvipdf and advi to programs that complete on .dvi
    files
  * iconv completion improvement
  * Replace invoke-rc.d completion
- move useful completion files to /etc/bash_completion.d/
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Aug  2 2005 cthiel@suse.de
- Update to version 20050721.
* Mon Mar  7 2005 agruen@suse.de
- Update to version 20050121.
* Tue Sep 21 2004 agruen@suse.de
- Update to version 20040711. Drop obsolete patches.
* Mon Feb 23 2004 hmacht@suse.de
- added option # norootforbuild in specfile
* Thu Sep 18 2003 agruen@suse.de
- #30648: fix insmod tab completion regexp quoting bug.
* Wed Sep  3 2003 agruen@suse.de
- rschiele@uni-mannheim.de: bash_completion searches lsmod in
  /sbin, but it is in /bin now.
* Mon Jul 28 2003 agruen@suse.de
- Remove /etc/bash_completion.d/ directory from files list: This
  directory is now "owned" by bash. (We still must create an
  /etc directory in the build root, though.)
* Fri Jul 25 2003 agruen@suse.de
- Mark /usr/share/doc/packages/bash-completion/ as owned by that
  package (RPMv4 complained about that).
* Thu Jul 24 2003 agruen@suse.de
- Create initial package.
